use strict;
use warnings FATAL => 'all';
use ExtUtils::MakeMaker;

(do 'maint/Makefile.PL.include' or die $@) unless -f 'META.yml';

require Alien::MoarVM;

(my $moar_root = $INC{"Alien/MoarVM.pm"}) =~ s/\.pm$/\/Install/;

WriteMakefile(
  NAME => 'Alien::NQP',
  VERSION_FROM => 'lib/Alien/NQP.pm',
  PMLIBDIRS => [ 'lib' ],
  META_MERGE => {
    configure_requires => { 'Alien::MoarVM' => 0 },
    no_index => { directory => [ 'nqp' ] },
  },
);

sub MY::postamble { (my $str = <<'END') =~ s{MOAR_ROOT}{$moar_root}g; $str; }

ALIENTARGET=$(INSTALLSITEARCH)/Alien/NQP/Install

all :: alienblib
	 touch blib/arch/auto/Alien/NQP/force-arch

nqp :
	 tar xzf ../rakudo-star-$(VERSION).tar.gz rakudo-star-$(VERSION)/nqp --strip-components=1

nqp/Makefile :
	 cd nqp; $(PERL) Configure.pl --prefix=$(ALIENTARGET) --backends=moar --with-moar=`which moar`
	 perl -pi -e 's{\S+(?=share/nqp/lib/MAST/)}{MOAR_ROOT/}' nqp/Makefile

alieninst : nqp/Makefile
	 cd nqp; make PREFIX=$(ALIENTARGET) DESTDIR=../alieninst MOAR=`which moar` install
	 perl -pi -e 's{$(ALIENTARGET)}{MOAR_ROOT}' alieninst/$(ALIENTARGET)/bin/*

alienblib : alieninst
	 mkdir -p blib/lib/Alien/NQP/
	 cp -a alieninst/$(ALIENTARGET)/bin blib/
	 cp -a alieninst/$(ALIENTARGET) blib/lib/Alien/NQP/

clean ::
	cd nqp; make clean
	rm nqp/Makefile
	rm -rf alieninst

END
